pub struct Sequence<'a> { /* private fields */ }Expand description
Stores the slice view of a contiguous column data table.
It doesn’t matter how the data is represented.
The only thing that matters is that
the column table is contiguous in memory,
and that the structure holding the memory
can be represented as a slice view
of u8 elements. Slices of primitive types
automatically can be cast to this kind of
slice view, by using From trait.
Implementations
Sourceimpl<'a> Sequence<'a>
impl<'a> Sequence<'a>
Sourcepub fn from_raw_parts<T>(slice: &'a [T], is_signed: bool) -> Self
pub fn from_raw_parts<T>(slice: &'a [T], is_signed: bool) -> Self
Converts a slice of any type to a Sequence by calling from_raw_parts on it.
The is_signed parameter is used to determine whether the data is interpreted as a signed value or not.
Several types are also supported via the From trait, which is preferred over this method.
The size of the elements in the slice must be between 1 and 16 bytes (inclusive) if is_signed is true,
and between 1 and 32 bytes (inclusive) if is_signed is false.
Sourcepub fn from_raw_parts_with_size<T>(
slice: &'a [T],
element_size: usize,
is_signed: bool,
) -> Self
pub fn from_raw_parts_with_size<T>( slice: &'a [T], element_size: usize, is_signed: bool, ) -> Self
Converts a slice of any type to a Sequence by calling from_raw_parts on it.
The is_signed parameter is used to determine whether the data is interpreted as a signed value or not.
The element_size parameter specifies the size of each element in bytes.